@@ -1,3 +1,4 @@
+#include <glib.h>
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  * lt-ext-module-data.h
@@ -35,7 +36,7 @@ struct _LtExtModuleData {
 typedef struct _LtExtModuleData	LtExtModuleData;
 
 
-LtExtModuleData *lt_ext_module_data_new  (size_t                size,
+LtExtModuleData *lt_ext_module_data_new  (gsize                size,
 					       LtDestroyFunc     finalizer);
 LtExtModuleData *lt_ext_module_data_ref  (LtExtModuleData *data);
 void                  lt_ext_module_data_unref(LtExtModuleData *data);
